@@ -17,6 +17,7 @@
  *
  */
 
+#include <limits.h>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -85,35 +86,45 @@ static double build_pcm(signed short *pcm, int samples, int rate,
     vol = start_vol;
     gradient = (end_vol - start_vol) / samples;
 
-    for(s = 0; s < samples; s++) {
+    for (s = 0; s < samples; s++) {
         int c, sa, q;
         float f, i[PLAYER_CHANNELS][4];
 
         /* 4-sample window for interpolation */
 
         sa = (int)sample;
-        if(sample < 0.0)
+        if (sample < 0.0)
             sa--;
         f = sample - sa;
         sa--;
 
-        for(q = 0; q < 4; q++, sa++) {
-            if(sa < 0 || sa >= tr->length) {
-                for(c = 0; c < PLAYER_CHANNELS; c++)
+        for (q = 0; q < 4; q++, sa++) {
+            if (sa < 0 || sa >= tr->length) {
+                for (c = 0; c < PLAYER_CHANNELS; c++)
                     i[c][q] = 0.0;
             } else {
                 signed short *ts;
                 int c;
 
                 ts = track_get_sample(tr, sa);
-                for(c = 0; c < PLAYER_CHANNELS; c++)
+                for (c = 0; c < PLAYER_CHANNELS; c++)
                     i[c][q] = (float)ts[c];
             }
         }
 
-        for(c = 0; c < PLAYER_CHANNELS; c++) {
-            *pcm++ = vol * cubic_interpolate(i[c], f)
+        for (c = 0; c < PLAYER_CHANNELS; c++) {
+            float v;
+
+            v = vol * cubic_interpolate(i[c], f)
                 + (float)(rand() % 32768) / 32768 - 0.5; /* dither */
+
+            if (v > SHRT_MAX) {
+                *pcm++ = SHRT_MAX;
+            } else if (v < SHRT_MIN) {
+                *pcm++ = SHRT_MIN;
+            } else {
+                *pcm++ = (signed short)v;
+            }
         }
 
         sample += step;
@@ -171,7 +182,7 @@ static int sync_to_timecode(struct player_t *pl)
     /* Instruct the caller to disconnect the timecoder if the needle
      * is outside the 'safe' zone of the record */
 
-    if(timecode != -1 && timecode > timecoder_get_safe(pl->timecoder))
+    if (timecode != -1 && timecode > timecoder_get_safe(pl->timecoder))
         return -1;
 
     /* If the timecoder is alive, use the pitch from the sine wave */
@@ -180,7 +191,7 @@ static int sync_to_timecode(struct player_t *pl)
 
     /* If we can read an absolute time from the timecode, then use it */
     
-    if(timecode == -1)
+    if (timecode == -1)
 	pl->target_valid = 0;
 
     else {
@@ -204,20 +215,20 @@ int player_recue(struct player_t *pl)
 
 /* Get a block of PCM audio data to send to the soundcard. */
 
-int player_collect(struct player_t *pl, signed short *pcm,
-                   int samples, int rate)
+void player_collect(struct player_t *pl, signed short *pcm,
+                    int samples, int rate)
 {
     double diff;
     float dt, target_volume;
 
     dt = (float)samples / rate;
 
-    if(pl->timecoder) {
+    if (pl->timecoder) {
         if (sync_to_timecode(pl) == -1)
             player_disconnect_timecoder(pl);
     }
 
-    if(!pl->target_valid) {
+    if (!pl->target_valid) {
 
         /* Without timecode sync, tend sync_pitch towards 1.0, to
          * avoid using outlier values from scratching for too long */
@@ -230,7 +241,7 @@ int player_collect(struct player_t *pl, signed short *pcm,
          * on the vinyl so that the current position is right under
          * the needle, and continue */
 
-        if(pl->reconnect) {
+        if (pl->reconnect) {
             pl->offset += pl->target_position - pl->position;
 	    pl->position = pl->target_position;
             pl->reconnect = 0;
@@ -242,14 +253,14 @@ int player_collect(struct player_t *pl, signed short *pcm,
         diff = pl->position - pl->target_position;
         pl->last_difference = diff; /* to print in user interface */
         
-        if(fabs(diff) > SKIP_THRESHOLD) {
+        if (fabs(diff) > SKIP_THRESHOLD) {
 
             /* Jump the track to the time */
             
             pl->position = pl->target_position;
             fprintf(stderr, "Seek to new position %.2lfs.\n", pl->position);
 
-        } else if(fabs(pl->pitch) > SYNC_PITCH) {
+        } else if (fabs(pl->pitch) > SYNC_PITCH) {
 
             /* Re-calculate the drift between the timecoder pitch from
              * the sine wave and the timecode values */
@@ -264,7 +275,7 @@ int player_collect(struct player_t *pl, signed short *pcm,
     }
 
     target_volume = fabs(pl->pitch) * VOLUME;
-    if(target_volume > 1.0)
+    if (target_volume > 1.0)
         target_volume = 1.0;
 
     /* Sync pitch is applied post-filtering */
@@ -276,8 +287,6 @@ int player_collect(struct player_t *pl, signed short *pcm,
                               pl->volume, target_volume);
     
     pl->volume = target_volume;
-
-    return 0;
 }
 
 
