@@ -36,29 +36,29 @@ int rig_init(struct rig_t *rig)
 {
     int n;
 
-    for(n = 0; n < MAX_DEVICES; n++) 
+    for (n = 0; n < MAX_DEVICES; n++)
         rig->device[n] = NULL;
 
-    for(n = 0; n < MAX_TRACKS; n++) 
+    for (n = 0; n < MAX_TRACKS; n++)
         rig->track[n] = NULL;
     
-    for(n = 0; n < MAX_PLAYERS; n++) 
+    for (n = 0; n < MAX_PLAYERS; n++)
         rig->player[n] = NULL;
     
-    for(n = 0; n < MAX_TIMECODERS; n++) 
+    for (n = 0; n < MAX_TIMECODERS; n++)
         rig->timecoder[n] = NULL;
 
     return 0;
 }
 
 
-int rig_service(struct rig_t *rig)
+static int rig_service(struct rig_t *rig)
 {
     int r, n;
     char buf;
     struct pollfd pt[MAX_TRACKS], *pe;
     
-    while(!rig->finished) {
+    while (!rig->finished) {
         pe = pt;
 
         /* ppoll() is not widely available, so use a pipe between this
@@ -72,22 +72,22 @@ int rig_service(struct rig_t *rig)
 
         /* Fetch file descriptors to monitor from each track */
 
-        for(n = 0; n < MAX_TRACKS; n++) {
-            if(rig->track[n])
+        for (n = 0; n < MAX_TRACKS; n++) {
+            if (rig->track[n])
                 pe += track_pollfd(rig->track[n], pe);
         }
 
         r = poll(pt, pe - pt, -1);
         
-        if(r == -1 && errno != EINTR) {
+        if (r == -1 && errno != EINTR) {
             perror("poll");
             return -1;
         }
 
         /* If we were awakened, take the top byte off the event pipe */
 
-        if(pt[0].revents) {
-            if(read(rig->event[0], &buf, 1) == -1) {
+        if (pt[0].revents) {
+            if (read(rig->event[0], &buf, 1) == -1) {
                 perror("read");
                 return -1;
             }
@@ -95,8 +95,8 @@ int rig_service(struct rig_t *rig)
 
         /* Do any reading and writing on all tracks */
 
-        for(n = 0; n < MAX_TRACKS; n++) {
-            if(rig->track[n])
+        for (n = 0; n < MAX_TRACKS; n++) {
+            if (rig->track[n])
                 track_handle(rig->track[n]);
         }
     }
@@ -105,7 +105,7 @@ int rig_service(struct rig_t *rig)
 }
 
 
-int rig_realtime(struct rig_t *rig)
+static int rig_realtime(struct rig_t *rig)
 {
     int r, n, max_pri;
     struct sched_param sp;
@@ -114,7 +114,7 @@ int rig_realtime(struct rig_t *rig)
     
     fprintf(stderr, "Setting scheduler priority...\n");
     
-    if(sched_getparam(0, &sp)) {
+    if (sched_getparam(0, &sp)) {
         perror("sched_getparam");
         return -1;
     }
@@ -122,29 +122,29 @@ int rig_realtime(struct rig_t *rig)
     max_pri = sched_get_priority_max(SCHED_FIFO);
     sp.sched_priority = REALTIME_PRIORITY;
 
-    if(sp.sched_priority > max_pri) {
+    if (sp.sched_priority > max_pri) {
         fprintf(stderr, "Invalid scheduling priority (maximum %d).\n",
                 max_pri);
         return -1;
 
     }
     
-    if(sched_setscheduler(0, SCHED_FIFO, &sp)) {
+    if (sched_setscheduler(0, SCHED_FIFO, &sp)) {
         perror("sched_setscheduler");
         fprintf(stderr, "Failed to set scheduler. Run as root otherwise you "
                 "may get wow and skips!\n");
     }
 
-    while(!rig->finished) {        
+    while (!rig->finished) {
         r = poll(rig->pt, rig->npt, -1);
         
-        if(r == -1 && errno != EINTR) {
+        if (r == -1 && errno != EINTR) {
             perror("poll");
             return -1;
         }
 
-        for(n = 0; n < MAX_DEVICES; n++) {
-            if(rig->device[n])
+        for (n = 0; n < MAX_DEVICES; n++) {
+            if (rig->device[n])
                 device_handle(rig->device[n]);
         }
     }
@@ -153,14 +153,14 @@ int rig_realtime(struct rig_t *rig)
 }
 
 
-void* service(void *p)
+static void* service(void *p)
 {
     rig_service(p);
     return p;
 }
 
 
-void* realtime(void *p)
+static void* realtime(void *p)
 {
     rig_realtime(p);
     return p;
@@ -177,19 +177,19 @@ int rig_start(struct rig_t *rig)
 
     /* Register ourselves with the tracks we are looking after */
 
-    for(n = 0; n < MAX_TRACKS; n++) {
-        if(rig->track[n])
+    for (n = 0; n < MAX_TRACKS; n++) {
+        if (rig->track[n])
             rig->track[n]->rig = rig;
     }
 
     /* Create a pipe which will be used to wake the service thread */
 
-    if(pipe(rig->event) == -1) {
+    if (pipe(rig->event) == -1) {
         perror("pipe");
         return -1;
     }
 
-    if(pthread_create(&rig->pt_service, NULL, service, (void*)rig)) {
+    if (pthread_create(&rig->pt_service, NULL, service, (void*)rig)) {
         perror("pthread_create");
         return -1;
     }
@@ -200,14 +200,14 @@ int rig_start(struct rig_t *rig)
     pe = rig->pt;
     pm = rig->pt + MAX_DEVICE_POLLFDS;
 
-    for(n = 0; n < MAX_DEVICES; n++) {
+    for (n = 0; n < MAX_DEVICES; n++) {
         dv = rig->device[n];
         
-        if(!dv)
+        if (!dv)
             continue;
         
         r = device_pollfds(dv, pe, pm - pe);
-        if(r == -1) {
+        if (r == -1) {
             fprintf(stderr, "Device failed to return file descriptors.\n");
             return -1;
         }
@@ -216,7 +216,7 @@ int rig_start(struct rig_t *rig)
 
         /* Start the audio rolling on the device */
 
-        if(device_start(dv) == -1)
+        if (device_start(dv) == -1)
             return -1;
     }
 
@@ -225,10 +225,10 @@ int rig_start(struct rig_t *rig)
     /* If there are any devices which returned file descriptors for
      * poll() then launch the realtime thread to handle them */
 
-    if(rig->npt > 0) {
+    if (rig->npt > 0) {
         fprintf(stderr, "Launching realtime thread to handle devices...\n");
 
-        if(pthread_create(&rig->pt_realtime, NULL, realtime, (void*)rig)) {
+        if (pthread_create(&rig->pt_realtime, NULL, realtime, (void*)rig)) {
             perror("pthread_create");
             return -1;
         }
@@ -244,7 +244,7 @@ int rig_awaken(struct rig_t *rig)
 {
     /* Send a single byte down the event pipe to a waiting poll() */
 
-    if(write(rig->event[1], "\0", 1) == -1) {
+    if (write(rig->event[1], "\0", 1) == -1) {
         perror("write");
         return -1;
     }
@@ -259,8 +259,8 @@ int rig_stop(struct rig_t *rig)
 
     rig->finished = 1;
 
-    if(rig->npt > 0) {
-        if(pthread_join(rig->pt_realtime, NULL) != 0) {
+    if (rig->npt > 0) {
+        if (pthread_join(rig->pt_realtime, NULL) != 0) {
             perror("pthread_join");
             return -1;
         }
@@ -268,14 +268,14 @@ int rig_stop(struct rig_t *rig)
 
     /* Stop audio rolling on devices */
 
-    for(n = 0; n < MAX_DEVICES; n++) {
-        if(rig->device[n])
+    for (n = 0; n < MAX_DEVICES; n++) {
+        if (rig->device[n])
             device_stop(rig->device[n]);
     }
 
     rig_awaken(rig);
 
-    if(pthread_join(rig->pt_service, NULL) != 0) {
+    if (pthread_join(rig->pt_service, NULL) != 0) {
         perror("pthread_join");
         return -1;
     }
